==> cmsmadesimple-1.5.3-full.tar.gz: modules/FileManager/lang/ext/it_IT.php <==
<?php
$lang['friendlyname'] = 'File Manager';
$lang['permission'] = 'Uso del modulo File Manager';
$lang['permissionadvanced'] = 'Uso avanzato del modulo File Manager';
$lang['moddescription'] = 'Associazione di files e directory nella sezione upload di cmsms';
$lang['installed'] = 'Versione del FileManager %s installata';
$lang['postinstall'] = 'Il modulo FileManager era installato';
$lang['uninstalled'] = 'Modulo FileManager disinstallato';
$lang['really_uninstall'] = 'Siete sicuri di volere disinstallare il modulo FileManager?';
$lang['upgraded'] = 'Il modulo FileManager &egrave; stato aggiornato alla versione %s';
$lang['fileview'] = 'Visualizza file';
$lang['switchtofileview'] = 'Passa alla visualizzazione file';
$lang['settings'] = 'Impostazioni';
$lang['savesettings'] = 'Salva Impostazioni';
$lang['filename'] = 'Nome file';
$lang['fileinfo'] = 'Info file';
$lang['fileowner'] = 'Possessore del file';
$lang['fileperms'] = 'Permessi';
$lang['filesize'] = 'Dimensione';
$lang['filedate'] = 'Data';
$lang['actions'] = 'Azioni';
$lang['delete'] = 'Elimina';
$lang['notwritable'] = 'Non scrivibile';
$lang['filetoobig'] = 'troppo grande. Upload cancellato.';
$lang['unknown'] = 'Sconosciuto';
$lang['fileoutsideuploads'] = 'Voi non avete il permesso di modificare file al di fuori della directory di uploads! (Questo richiede permessi di Advanced File Management)';
$lang['writable'] = 'Scrivibile';
$lang['writeprotected'] = 'Protetto da scrittura';
$lang['bytes'] = 'bytes';
$lang['kb'] = 'KB';
$lang['mb'] = 'MB';
$lang['files'] = 'files';
$lang['bytesin'] = 'bytes in';
$lang['in'] = 'in';
$lang['file'] = 'file';
$lang['fileno'] = 'File numero';
$lang['subdirs'] = 'sottodirectory';
$lang['subdir'] = 'sottodirectory';
$lang['and'] = 'e';
$lang['confirmsingledelete'] = 'Siete sicuri?';
$lang['confirmsingledirdelete'] = 'Siete sicuri di volere cancellare questa directory?';
$lang['dirtreedeletesuccess'] = 'La directory e tutto il suo contenuto &egrave; stata cancellata con successo.';
$lang['dirtreedeletefail'] = 'C&#039;&egrave; stato un errore durante l&#039;eliminazione di questa directory. Tuttavia una parte del contenuto potrebbe essere stata cancellata.';
$lang['singlefiledeletesuccess'] = 'Il file &egrave; stato eliminato con successo';
$lang['filedeletesuccess'] = '&egrave; stato eliminato con successo';
$lang['singlefiledeletefail'] = 'Si &egrave; verificato un errore durante l&#039;eliminazione del file';
$lang['filedeletefail'] = 'non &egrave; stato eliminato a causa di un errore';
$lang['singledirdeletesuccess'] = 'La directory &egrave; stata eliminata con successo';
$lang['singledirdeletefail'] = 'Si &egrave; verificato un errore cercando di eliminare la directory (&egrave; vuota?)';
$lang['deleteselected'] = 'Elimina i file selezionati';
$lang['confirmselected'] = 'Siete sicuri?';
$lang['confirmdeleteselected'] = 'Siete sicuri che i file selezionati devono essere cancellati?';
$lang['deleteselectedcancelled'] = 'Cancellazione dei file selezionati annullata';
$lang['recursetext'] = 'Ricorsivo nelle sottodirectory (non ancora implementato)';
$lang['nofilesselected'] = 'Nessun file selezionato';
$lang['moveselected'] = 'Muove i file selezionati';
$lang['copyselected'] = 'Copia i file selezionati';
$lang['selecttargetdir'] = 'Selezionate la directory di arrivo per muovere/copiare';
$lang['movedto'] = 'mosso a';
$lang['copiedto'] = 'copiato a';
$lang['couldnotmove'] = 'non pu&ograve; essere mosso';
$lang['couldnotcopy'] = 'non pu&ograve; essere copiato';
$lang['rename'] = 'Rinomina';
$lang['newname'] = 'Nuovo nome:';
$lang['renamesuccess'] = 'File rinominato correttamente';
$lang['renamefailure'] = 'Modifica del nome fallita';
$lang['renamecancelled'] = 'Modifica del nome annullata';
$lang['owner'] = 'Proprietario';
$lang['group'] = 'Gruppo';
$lang['others'] = 'Altri';
$lang['newpermissions'] = 'Nuovi permessi:';
$lang['setpermissions'] = 'Imposta permessi';
$lang['permissionstyle'] = 'Stile permessi';
$lang['rwxstyle'] = 'stile rwx';
$lang['755style'] = 'stile 755';
$lang['quickmode'] = 'chmod veloce (like 777)';
$lang['chmod'] = 'Cambia permessi';
$lang['chmodselected'] = 'Cambia permessi sui file selezionati';
$lang['chmodsuccess'] = 'File modificato con i nuovi permessi';
$lang['chmodfailure'] = 'Cambio dei permessi del file fallito';
$lang['chmodcancelled'] = 'Cambio dei permessi cancellato';
$lang['dirchmodfailmulti'] = 'Il cambio dei permessi sulla directory &egrave; fallito, sebbene alcuni dei componenti potrebbero aver preso i nuovi permessi.';
$lang['dirchmodsuccessmulti'] = 'Il cambio dei permessi sulla directory e i suoi componenti ha avuto successo';
$lang['dirchmodsuccess'] = 'La directory ha preso correttamente i nuovi permessi';
$lang['dirchmodfailure'] = 'Cambio dei permessi della directory fallito';
$lang['dirnotemptyconfirm'] = 'La directory non &egrave; vuota. Volete veramente eliminarla cancellando il suo contenuto, comprese le sottodirectory?';
$lang['dirtreedeletecancelled'] = 'Eliminazione della directory annnullata';
$lang['imsure'] = 'Sono sicuro';
$lang['cancel'] = 'Annulla';
$lang['ok'] = 'OK';
$lang['uploadnewfile'] = 'Carica nuovo/i file:';
$lang['unpackafterupload'] = 'Cerca di decomprimere dopo il caricamento (solo file di tipo tgz e zip)?';
$lang['uploadsuccess'] = 'Il file &egrave; stato caricato con successo';
$lang['uploadfail'] = 'Si &egrave; verificato un errore durante il caricamento del file';
$lang['unpacksuccess'] = 'Il file &egrave; stato decompresso con successo';
$lang['unpackfail'] = 'Si &egrave; verificato un errore durante la decompressione del file:';
$lang['packfileopenfail'] = 'Non posso aprire il file compresso per la decompressione (formato non supportato?)';
$lang['packfilewritefail'] = 'Non posso aprire il file %s per la scrittura';
$lang['currentpath'] = 'Path corrente:';
$lang['newdirname'] = 'Crea nuova directory:';
$lang['newdirsuccess'] = 'La directory &egrave; stata creata con successo';
$lang['newdirfail'] = 'Si &egrave; verificato un errore durante la creazione della directory';
$lang['filedateformat'] = 'd/m/Y H:m:s';
$lang['iconsize'] = 'Dimensione Icona';
$lang['smallicons'] = 'Icone Piccole';
$lang['largeicons'] = 'Icone Grandi';
$lang['thousanddelimiter'] = 'Delimitatore delle migliaia';
$lang['none'] = 'Nessuno';
$lang['showthumbnails'] = 'Mostra le miniature';
$lang['showthumbnailshelp'] = 'Abilitando vengono mostrate le miniature dei file immagini se esistono e nascosti i file miniature. Disabilitando vengono mostrati tutti i file.';
$lang['uploadfilesto'] = 'Carica i files in:';
$lang['uploadview'] = 'Carica files';
$lang['uploadboxes'] = 'Numero di blocchi di caricamento';
$lang['nothinguploaded'] = 'Non &egrave; stato caricato nulla';
$lang['unsupportedarchive'] = 'Formato di archivio non supportato';
$lang['uploadmethod'] = 'Metodo di caricamento';
$lang['uploaderstandard'] = 'Metodo di input html standard (permette la decompressione)';
$lang['enableadvanced'] = 'Abilita modalit&agrave; avanzata?';
$lang['advancedhelp'] = 'Permette di ottenere accesso a tutto il filesystem di CMSMS, non solo della cartella /upload/ (se consentito)';
$lang['showhiddenfileshelp'] = 'Effettivo solo abilitando il modo avanzato';
$lang['showhiddenfiles'] = 'Mostra file nascosti';
$lang['settingsconfirmsingledelete'] = 'Conferma l&#039;eliminazione di un file singolo?';
$lang['settingssaved'] = 'Impostazioni salvate';
$lang['help'] = '		<h3>Cosa fa?</h3>
		<p>Fornisce funzionalit&agrave; di gestione dei file</p>
		<h3>Come si usa?</h3>
		<p>Selezionalo dal menu Contenuto nella sezione di amministrazione.</p>';
$lang['utmz'] = '156861353.1228168733.609.121.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
$lang['utma'] = '156861353.1807151640.1182960456.1227740242.1228168733.609';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
?>

==> cmsmadesimple-1.7.1-full.tar.gz: modules/FileManager/lang/ext/it_IT.php <==
<?php
$lang['friendlyname'] = 'File Manager';
$lang['permission'] = 'Uso del modulo File Manager';
$lang['permissionadvanced'] = 'Uso avanzato del modulo File Manager';
$lang['moddescription'] = 'Associazione di files e directory nella sezione upload di cmsms';
$lang['installed'] = 'Versione del FileManager %s installata';
$lang['postinstall'] = 'Il modulo FileManager era installato';
$lang['uninstalled'] = 'Modulo FileManager disinstallato';
$lang['really_uninstall'] = 'Siete sicuri di volere disinstallare il modulo FileManager?';
$lang['upgraded'] = 'Il modulo FileManager &egrave; stato aggiornato alla versione %s';
$lang['fileview'] = 'Visualizza file';
$lang['switchtofileview'] = 'Passa alla visualizzazione file';
$lang['settings'] = 'Impostazioni';
$lang['savesettings'] = 'Salva Impostazioni';
$lang['filename'] = 'Nome file';
$lang['fileinfo'] = 'Info file';
$lang['fileowner'] = 'Possessore del file';
$lang['fileperms'] = 'Permessi';
$lang['filesize'] = 'Dimensione';
$lang['filedate'] = 'Data';
$lang['actions'] = 'Azioni';
$lang['delete'] = 'Elimina';
$lang['notwritable'] = 'Non scrivibile';
$lang['filetoobig'] = 'troppo grande. Upload cancellato.';
$lang['unknown'] = 'Sconosciuto';
$lang['fileoutsideuploads'] = 'Voi non avete il permesso di modificare file al di fuori della directory di uploads! (Questo richiede permessi di Advanced File Management)';
$lang['writable'] = 'Scrivibile';
$lang['writeprotected'] = 'Protetto da scrittura';
$lang['bytes'] = 'bytes';
$lang['kb'] = 'KB';
$lang['mb'] = 'MB';
$lang['files'] = 'file';
$lang['bytesin'] = 'bytes in';
$lang['in'] = 'in';
$lang['file'] = 'file';
$lang['fileno'] = 'File numero';
$lang['subdirs'] = 'sottodirectory';
$lang['subdir'] = 'sottodirectory';
$lang['and'] = 'e';
$lang['confirmsingledelete'] = 'Siete sicuri?';
$lang['confirmsingledirdelete'] = 'Siete sicuri di volere cancellare questa directory?';
$lang['dirtreedeletesuccess'] = 'La directory e tutto il suo contenuto &egrave; stata cancellata con successo.';
$lang['dirtreedeletefail'] = 'C&#039;&egrave; stato un errore durante l&#039;eliminazione di questa directory. Tuttavia una parte del contenuto potrebbe essere stata cancellata.';
$lang['singlefiledeletesuccess'] = 'Il file &egrave; stato eliminato con successo';
$lang['filedeletesuccess'] = '&egrave; stato eliminato con successo';
$lang['singlefiledeletefail'] = 'Si &egrave; verificato un errore durante l&#039;eliminazione del file';
$lang['filedeletefail'] = 'non &egrave; stato eliminato a causa di un errore';
$lang['singledirdeletesuccess'] = 'La directory &egrave; stata eliminata con successo';
$lang['singledirdeletefail'] = 'Si &egrave; verificato un errore cercando di eliminare la directory (&egrave; vuota?)';
$lang['deleteselected'] = 'Elimina i file selezionati';
$lang['confirmselected'] = 'Siete sicuri?';
$lang['confirmdeleteselected'] = 'Siete sicuri che i file selezionati devono essere cancellati?';
$lang['deleteselectedcancelled'] = 'Cancellazione dei file selezionati annullata';
$lang['recursetext'] = 'Ricorsivo nelle sottodirectory (non ancora implementato)';
$lang['nofilesselected'] = 'Nessun file selezionato';
$lang['moveselected'] = 'Muove i file selezionati';
$lang['copyselected'] = 'Copia i file selezionati';
$lang['selecttargetdir'] = 'Selezionate la directory di arrivo per muovere/copiare';
$lang['movedto'] = 'mosso a';
$lang['copiedto'] = 'copiato a';
$lang['couldnotmove'] = 'non pu&ograve; essere mosso';
$lang['couldnotcopy'] = 'non pu&ograve; essere copiato';
$lang['rename'] = 'Rinomina';
$lang['newname'] = 'Nuovo nome:';
$lang['renamesuccess'] = 'File rinominato correttamente';
$lang['renamefailure'] = 'Modifica del nome fallita';
$lang['renamecancelled'] = 'Modifica del nome annullata';
$lang['owner'] = 'Proprietario';
$lang['group'] = 'Gruppo';
$lang['others'] = 'Altri';
$lang['newpermissions'] = 'Nuovi permessi:';
$lang['setpermissions'] = 'Imposta permessi';
$lang['permissionstyle'] = 'Stile permessi';
$lang['rwxstyle'] = 'stile rwx';
$lang['755style'] = 'stile 755';
$lang['quickmode'] = 'chmod veloce (like 777)';
$lang['chmod'] = 'Cambia permessi';
$lang['chmodselected'] = 'Cambia permessi sui file selezionati';
$lang['chmodsuccess'] = 'File modificato con i nuovi permessi';
$lang['chmodfailure'] = 'Cambio dei permessi del file fallito';
$lang['chmodcancelled'] = 'Cambio dei permessi cancellato';
$lang['dirchmodfailmulti'] = 'Il cambio dei permessi sulla directory &egrave; fallito, sebbene alcuni dei componenti potrebbero aver preso i nuovi permessi.';
$lang['dirchmodsuccessmulti'] = 'Il cambio dei permessi sulla directory e i suoi componenti ha avuto successo';
$lang['dirchmodsuccess'] = 'La directory ha preso correttamente i nuovi permessi';
$lang['dirchmodfailure'] = 'Cambio dei permessi della directory fallito';
$lang['dirnotemptyconfirm'] = 'La directory non &egrave; vuota. Volete veramente eliminarla cancellando il suo contenuto, comprese le sottodirectory?';
$lang['dirtreedeletecancelled'] = 'Eliminazione della directory annnullata';
$lang['imsure'] = 'Sono sicuro';
$lang['cancel'] = 'Annulla';
$lang['ok'] = 'OK';
$lang['uploadnewfile'] = 'Carica nuovo/i file:';
$lang['unpackafterupload'] = 'Cerca di decomprimere dopo il caricamento (solo file di tipo tgz e zip)?';
$lang['uploadsuccess'] = 'Il file &egrave; stato caricato con successo';
$lang['uploadfail'] = 'Si &egrave; verificato un errore durante il caricamento del file';
$lang['unpacksuccess'] = 'Il file &egrave; stato decompresso con successo';
$lang['unpackfail'] = 'Si &egrave; verificato un errore durante la decompressione del file:';
$lang['packfileopenfail'] = 'Non posso aprire il file compresso per la decompressione (formato non supportato?)';
$lang['packfilewritefail'] = 'Non posso aprire il file %s per la scrittura';
$lang['containsillegalchars'] = 'Filename contiene uno o pi&ugrave; caratteri illegali (&#039;,&quot;,+,*,\,/,&amp;,$)';
$lang['currentpath'] = 'Path corrente:';
$lang['newdirname'] = 'Crea nuova directory:';
$lang['newdirsuccess'] = 'La directory &egrave; stata creata con successo';
$lang['newdirfail'] = 'Si &egrave; verificato un errore durante la creazione della directory';
$lang['invalidnewdir'] = 'Il nome della nuova cartella non pu&ograve; contenere caratteri come /, \ e &#039;..&#039;';
$lang['filedateformat'] = 'd/m/Y H:m:s';
$lang['iconsize'] = 'Dimensione Icona';
$lang['smallicons'] = 'Icone Piccole';
$lang['largeicons'] = 'Icone Grandi';
$lang['thousanddelimiter'] = 'Delimitatore delle migliaia';
$lang['none'] = 'Nessuno';
$lang['space'] = 'spazio';
$lang['showthumbnails'] = 'Mostra le miniature';
$lang['showthumbnailshelp'] = 'Abilitando vengono mostrate le miniature dei file immagini se esistono e nascosti i file miniature. Disabilitando vengono mostrati tutti i file.';
$lang['uploadfilesto'] = 'Carica i files in:';
$lang['uploadview'] = 'Carica files';
$lang['uploadboxes'] = 'Numero di blocchi di caricamento';
$lang['nothinguploaded'] = 'Non &egrave; stato caricato nulla';
$lang['unsupportedarchive'] = 'Formato di archivio non supportato';
$lang['uploadmethod'] = 'Metodo di caricamento';
$lang['uploaderstandard'] = 'Metodo di input html standard (permette la decompressione)';
$lang['enableadvanced'] = 'Abilita modalit&agrave; avanzata?';
$lang['advancedhelp'] = 'Permette di ottenere accesso a tutto il filesystem di CMSMS, non solo della cartella /upload/ (se consentito)';
$lang['showhiddenfileshelp'] = 'Effettivo solo abilitando il modo avanzato';
$lang['showhiddenfiles'] = 'Mostra file nascosti';
$lang['settingsconfirmsingledelete'] = 'Conferma l&#039;eliminazione di un file singolo?';
$lang['settingssaved'] = 'Impostazioni salvate';
$lang['help'] = '		<h3>Cosa fa?</h3>
		<p>Fornisce funzionalit&agrave; di gestione dei file</p>
		<h3>Come si usa?</h3>
		<p>Selezionalo dal menu Contenuto nella sezione di amministrazione.</p>';
$lang['qca'] = 'P0-341425854-1271258489279';
$lang['utma'] = '156861353.1785716972.1271258827.1272464498.1272484592.7';
$lang['utmz'] = '156861353.1272484592.7.6.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353.1.10.1272484592';
?>
